@@ -6,9 +6,9 @@ from datetime import datetime
 from enum import Enum
 from typing import List, Optional, Union
 
-try: 
+try:
     from typing import Literal
-except ImportError: # pragma: no cover
+except ImportError:  # pragma: no cover
     from typing_extensions import Literal
 
 from pydantic import Field, root_validator
@@ -287,8 +287,8 @@ class EphysRig(AindCoreModel):
 
     @root_validator
     def validate_device_names(cls, values):
-        """ validate that all DAQ channels are connected to devices that 
-            actually exist
+        """validate that all DAQ channels are connected to devices that
+        actually exist
         """
 
         cameras = values.get("cameras")
@@ -319,15 +319,17 @@ class EphysRig(AindCoreModel):
                 for channel in daq.channels:
                     if channel.device_name not in device_names:
                         raise ValueError(
-                            f"DAQ channel validation error: {channel.device_name} not found in device list"
+                            f"Device name validation error: '{channel.device_name}' " +  
+                            f"is connected to '{channel.channel_name}' on '{daq.name}', but " +
+                            "this device is not part of the rig."
                         )
 
         return values
 
     @root_validator
     def validate_probe_names(cls, values):
-        """ validate that all DAQ probe ports are connected to probes that 
-            actually exist 
+        """validate that all DAQ probe ports are connected to probes that
+        actually exist
         """
 
         ephys_modules = values.get("ephys_modules")
@@ -348,6 +350,10 @@ class EphysRig(AindCoreModel):
                     for port in daq.ports:
                         for probe in port.probes:
                             if probe not in probe_names:
-                                raise ValueError(f"DAQ port validation error: {probe} not found in probe list")
+                                raise ValueError(
+                                    f"Probe name validation error: '{probe}' " +  
+                                    f"is connected to '{daq.name}' port '{port.index}', but " +
+                                    "this probe is not part of the rig."
+                                )
 
         return values
